/* ########################################################################## */
/* STEP 3 */
/* ########################################################################## */
/* CALORIES.SAS */
/* ########################################################################## */
/* ########################################################################## */
/* Generates information about calories consumed per food
   item, and price paid for the calories */

/* Written by Suhas D. Parandekar, June 17, 1999 */
/* Last updated by Suhas D. Parandekar, January 3, 2000 */

/* ########################################################################## */

/* INPUT DATA - FIXED1 to FIXED84 (Consumption Expenditure,
   corrected for extreme values and miscodings, generated by the program ERROFIX1.SAS )
   also, a file called FOODIMP2.POR, provided by SIISE of Ecuador, which
   provides calorific values for the food items */

/* OUTPUT DATA - 85 separate data sets, called NIXED1 to NIXED84
                 which have the price per calorie information for each food item
                 Item 85, cigarettes, is excluded from this program */

/* OUTPUT OF DESCRIPTIVES - ERROFIX1.LST  provides means      */

/* ########################################################################## */
OPTIONS COMPRESS=YES LS=72 NOCENTER PAGENO=1;
LIBNAME SASDATA 'P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\data\newdata\sas';
LIBNAME SPDATA SPSS 'P:\General\Lcshd\Sdp\Ctry\Ecuador\foodvalu\foodimp2.por';

/* Specify Destination location for log and output (.lst) file */

PROC PRINTTO LOG='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\Calories.LOG'
             PRINT='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\Calories.LST';


%macro gastalim;

%let count=1;
%do %while(&count<85);
%put the value of count is &count;
DATA FOOD&count;
SET SASDATA.FIXED&count;
FORMAT HHID 14.;
/* Recover rural */
RURAL=GEOUNIT1-(DOMINIO*10);

/* Consumption in grams */
/* Daily */
IF UNIT = 1 AND FREQ = 1 THEN GRAMS=QUANTPUR;
IF UNIT = 2 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 3 AND FREQ = 1 THEN GRAMS=28.35*QUANTPUR;
IF UNIT = 4 AND FREQ = 1 THEN GRAMS=453.6*QUANTPUR;
IF UNIT = 5 AND FREQ = 1 THEN GRAMS=(453.6)*(25)*(QUANTPUR);
IF UNIT = 6 AND FREQ = 1 THEN GRAMS=45351.47*QUANTPUR;
IF UNIT = 7 AND FREQ = 1 THEN GRAMS=QUANTPUR; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 9 AND FREQ = 1 THEN GRAMS=3785.41*QUANTPUR;

/* Weekly */

IF UNIT = 1 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7;
IF UNIT = 2 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 3 AND FREQ = 2 THEN GRAMS=(28.35*QUANTPUR)/7;
IF UNIT = 4 AND FREQ = 2 THEN GRAMS=(453.6*QUANTPUR)/7;
IF UNIT = 5 AND FREQ = 2 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/7;
IF UNIT = 6 AND FREQ = 2 THEN GRAMS=(45351.47*QUANTPUR)/7;
IF UNIT = 7 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 9 AND FREQ = 2 THEN GRAMS=(3785.41*QUANTPUR)/7;

/* Fortnightly */

IF UNIT = 1 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14;
IF UNIT = 2 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 3 AND FREQ = 3 THEN GRAMS=(28.35*QUANTPUR)/14;
IF UNIT = 4 AND FREQ = 3 THEN GRAMS=(453.6*QUANTPUR)/14;
IF UNIT = 5 AND FREQ = 3 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/14;
IF UNIT = 6 AND FREQ = 3 THEN GRAMS=(45351.47*QUANTPUR)/14;
IF UNIT = 7 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 9 AND FREQ = 3 THEN GRAMS=(3785.41*QUANTPUR)/14;

/* Monthly */

IF UNIT = 1 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30;
IF UNIT = 2 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 3 AND FREQ = 4 THEN GRAMS=(28.35*QUANTPUR)/30;
IF UNIT = 4 AND FREQ = 4 THEN GRAMS=(453.6*QUANTPUR)/30;
IF UNIT = 5 AND FREQ = 4 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/30;
IF UNIT = 6 AND FREQ = 4 THEN GRAMS=(45351.47*QUANTPUR)/30;
IF UNIT = 7 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 9 AND FREQ = 4 THEN GRAMS=(3785.41*QUANTPUR)/30;

/* Three-Monthly */

IF UNIT = 1 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92;
IF UNIT = 2 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 4 AND FREQ = 5 THEN GRAMS=(453.6*QUANTPUR)/92;
IF UNIT = 5 AND FREQ = 5 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/92;
IF UNIT = 6 AND FREQ = 5 THEN GRAMS=(45351.47*QUANTPUR)/92;
IF UNIT = 7 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 9 AND FREQ = 5 THEN GRAMS=(3785.41*QUANTPUR)/92;

/* Six-Monthly */

IF UNIT = 1 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183;
IF UNIT = 2 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 3 AND FREQ = 6 THEN GRAMS=(28.35*QUANTPUR)/183;
IF UNIT = 4 AND FREQ = 6 THEN GRAMS=(453.6*QUANTPUR)/183;
IF UNIT = 5 AND FREQ = 6 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/183;
IF UNIT = 6 AND FREQ = 6 THEN GRAMS=(45351.47*QUANTPUR)/183;
IF UNIT = 7 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 9 AND FREQ = 6 THEN GRAMS=(3785.41*QUANTPUR)/183;

/* Yearly */

IF UNIT = 1 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366;
IF UNIT = 2 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 3 AND FREQ = 7 THEN GRAMS=(28.35*QUANTPUR)/366;
IF UNIT = 4 AND FREQ = 7 THEN GRAMS=(453.6*QUANTPUR)/366;
IF UNIT = 5 AND FREQ = 7 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/366;
IF UNIT = 6 AND FREQ = 7 THEN GRAMS=(45351.47*QUANTPUR)/366;
IF UNIT = 7 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 9 AND FREQ = 7 THEN GRAMS=(3785.41*QUANTPUR)/366;


IF NPERS GT 0 THEN GRAMPER=GRAMS/NPERS;
/* ************************************************* */

/* NON-PURCHASED ITEMS */

/* Daily */
IF UNITNPUR = 1 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR;
IF UNITNPUR = 2 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 3 AND FREQNPUR = 1 THEN GRAMSN=28.35*QUANNPUR;
IF UNITNPUR = 4 AND FREQNPUR = 1 THEN GRAMSN=453.6*QUANNPUR;
IF UNITNPUR = 5 AND FREQNPUR = 1 THEN GRAMSN=(453.6)*(25)*(QUANNPUR);
IF UNITNPUR = 6 AND FREQNPUR = 1 THEN GRAMSN=45351.47*QUANNPUR;
IF UNITNPUR = 7 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 9 AND FREQNPUR = 1 THEN GRAMSN=3785.41*QUANNPUR;

/* Weekly */

IF UNITNPUR = 1 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7;
IF UNITNPUR = 2 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 3 AND FREQNPUR = 2 THEN GRAMSN=(28.35*QUANNPUR)/7;
IF UNITNPUR = 4 AND FREQNPUR = 2 THEN GRAMSN=(453.6*QUANNPUR)/7;
IF UNITNPUR = 5 AND FREQNPUR = 2 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/7;
IF UNITNPUR = 6 AND FREQNPUR = 2 THEN GRAMSN=(45351.47*QUANNPUR)/7;
IF UNITNPUR = 7 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 9 AND FREQNPUR = 2 THEN GRAMSN=(3785.41*QUANNPUR)/7;

/* Fortnightly */

IF UNITNPUR = 1 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14;
IF UNITNPUR = 2 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 3 AND FREQNPUR = 3 THEN GRAMSN=(28.35*QUANNPUR)/14;
IF UNITNPUR = 4 AND FREQNPUR = 3 THEN GRAMSN=(453.6*QUANNPUR)/14;
IF UNITNPUR = 5 AND FREQNPUR = 3 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/14;
IF UNITNPUR = 6 AND FREQNPUR = 3 THEN GRAMSN=(45351.47*QUANNPUR)/14;
IF UNITNPUR = 7 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 9 AND FREQNPUR = 3 THEN GRAMSN=(3785.41*QUANNPUR)/14;

/* Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30;
IF UNITNPUR = 2 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 3 AND FREQNPUR = 4 THEN GRAMSN=(28.35*QUANNPUR)/30;
IF UNITNPUR = 4 AND FREQNPUR = 4 THEN GRAMSN=(453.6*QUANNPUR)/30;
IF UNITNPUR = 5 AND FREQNPUR = 4 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/30;
IF UNITNPUR = 6 AND FREQNPUR = 4 THEN GRAMSN=(45351.47*QUANNPUR)/30;
IF UNITNPUR = 7 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 9 AND FREQNPUR = 4 THEN GRAMSN=(3785.41*QUANNPUR)/30;

/* Three-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92;
IF UNITNPUR = 2 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 3 AND FREQNPUR = 5 THEN GRAMSN=(28.35*QUANNPUR)/92;
IF UNITNPUR = 4 AND FREQNPUR = 5 THEN GRAMSN=(453.6*QUANNPUR)/92;
IF UNITNPUR = 5 AND FREQNPUR = 5 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/92;
IF UNITNPUR = 6 AND FREQNPUR = 5 THEN GRAMSN=(45351.47*QUANNPUR)/92;
IF UNITNPUR = 7 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 9 AND FREQNPUR = 5 THEN GRAMSN=(3785.41*QUANNPUR)/92;

/* Six-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183;
IF UNITNPUR = 2 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 3 AND FREQNPUR = 6 THEN GRAMSN=(28.35*QUANNPUR)/183;
IF UNITNPUR = 4 AND FREQNPUR = 6 THEN GRAMSN=(453.6*QUANNPUR)/183;
IF UNITNPUR = 5 AND FREQNPUR = 6 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/183;
IF UNITNPUR = 6 AND FREQNPUR = 6 THEN GRAMSN=(45351.47*QUANNPUR)/183;
IF UNITNPUR = 7 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 9 AND FREQNPUR = 6 THEN GRAMSN=(3785.41*QUANNPUR)/183;

/* Yearly */

IF UNITNPUR = 1 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366;
IF UNITNPUR = 2 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 3 AND FREQNPUR = 7 THEN GRAMSN=(28.35*QUANNPUR)/366;
IF UNITNPUR = 4 AND FREQNPUR = 7 THEN GRAMSN=(453.6*QUANNPUR)/366;
IF UNITNPUR = 5 AND FREQNPUR = 7 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/366;
IF UNITNPUR = 6 AND FREQNPUR = 7 THEN GRAMSN=(45351.47*QUANNPUR)/366;
IF UNITNPUR = 7 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 9 AND FREQNPUR = 7 THEN GRAMSN=(3785.41*QUANNPUR)/366;

IF NPERS GT 0 THEN GRAMNPER=GRAMSN/NPERS;

/* Define total grams bought or obtained by household in past 14
   days, regardless of whether they consumed it or not */
/* This variable is TOTGRAM */

IF UNIT = 1  THEN TRAMS=QUANTPUR;
IF UNIT = 2  THEN TRAMS=1000*QUANTPUR;
IF UNIT = 3  THEN TRAMS=28.35*QUANTPUR;
IF UNIT = 4  THEN TRAMS=453.6*QUANTPUR;
IF UNIT = 5  THEN TRAMS=(453.6)*(25)*(QUANTPUR);
IF UNIT = 6  THEN TRAMS=45351.47*QUANTPUR;
IF UNIT = 7  THEN TRAMS=QUANTPUR; /* Pretend density is 1 */
IF UNIT = 8  THEN TRAMS=1000*QUANTPUR;
IF UNIT = 9  THEN TRAMS=3785.41*QUANTPUR;


IF UNITNPUR = 1  THEN TRAMSN=QUANNPUR;
IF UNITNPUR = 2  THEN TRAMSN=1000*QUANNPUR;
IF UNITNPUR = 3  THEN TRAMSN=28.35*QUANNPUR;
IF UNITNPUR = 4  THEN TRAMSN=453.6*QUANNPUR;
IF UNITNPUR = 5  THEN TRAMSN=(453.6)*(25)*(QUANNPUR);
IF UNITNPUR = 6  THEN TRAMSN=45351.47*QUANNPUR;
IF UNITNPUR = 7  THEN TRAMSN=QUANNPUR; /* Pretend density is 1 */
IF UNITNPUR = 8  THEN TRAMSN=1000*QUANNPUR;
IF UNITNPUR = 9  THEN TRAMSN=3785.41*QUANNPUR;

IF TRAMS = . THEN TRAMS=0;
IF TRAMSN = . THEN TRAMSN=0;
IF GRAMPER = . THEN GRAMPER=0;
IF GRAMNPER = . THEN GRAMNPER=0;
IF EXPEND= . THEN EXPEND=0;
IF EXPENPUR = . THEN EXPENPUR=0;



/* NO FREQUENCY USED ******************************************** */
/* Now "price" or unit value per gram */
IF TRAMS GT 0 AND EXPEND GT 0 THEN PRICE1=EXPEND/TRAMS;   /* Generally, the price we
                                                             want to use */
IF TRAMSN GT 0 AND EXPENPUR GT 0 THEN PRICE2=EXPENPUR/TRAMSN;
/* Now total grams by household in 14 days, without regard
   to frequency is from TRAMS and TRAMSN */
TOTGRAM=TRAMS+TRAMSN; /* Missings already converted to zero */

/* SPENDS for 2 weeks, regardless of frequency */
SPEND=EXPEND+EXPENPUR; /* Missings already converted to zero */



/* FREQUENCY USED ************************************************ */
/* Now spending imputed in 14 days for how many grams */   /* Generally, the quantity we
                                                              want to use */
GRAM1=GRAMPER*NPERS*14;
GRAM2=GRAMNPER*NPERS*14;

/* Daily Grams per person */
GRAM=GRAMPER+GRAMNPER;



/* COMBINED NO FREQUENCY AND FREQUENCY **************************** */
/* Imputed food consumption expenditure in 14 days */
SPEND1=GRAM1*PRICE1;
SPEND2=GRAM2*PRICE2;
IF SPEND1= . THEN SPEND1=0;
IF SPEND2= . THEN SPEND2=0;
SPENDING=SPEND1+SPEND2;
IF SPENDING = . THEN SPENDING=0;        /* Generally, the expenditure we want to use */

PROC SORT;BY FOODCD;



DATA SASDATA.FOODIMP2;SET SPDATA.FOODIMP2;
PROC SORT; BY FOODCD;

/* Calorific value from SIISE */


DATA SASDATA.MER;
MERGE FOOD&count(IN=IN1) SASDATA.FOODIMP2;BY FOODCD;
IF IN1;

/* kilocalories per person per day  */

NONWAST=(1-WAST);          /* Proportion edible */
CALORIES=KCAL*NONWAST;     /* Calories from given grams */

CALBWTOT=CALORIES*TOTGRAM;       /* no FREQ */
CALBWTO2=CALORIES*GRAM*NPERS*14; /* with FREQ */

IF CALBWTOT GT 0 THEN PRICECAL=(SPEND/CALBWTOT);  /* No freq used here */
IF CALBWTO2 GT 0 THEN PRICECA2=(SPENDING/CALBWTO2);  /* With freq used here */

DATA SASDATA.NIXED&count ;SET SASDATA.MER ;
FORMAT HHID 14.;
KEEP HHID REGION PROVINCE GEOUNIT1 GEOUNIT2 RURAL
     NPERS FOODCD FOOD95 WAST CALORIES
     SPEND TOTGRAM SPENDING GRAM
     CALBWTOT CALBWTO2
     PRICECAL PRICECA2;

LABEL
REGION="Region 1 Costa 2 Sierra 3 Oriente"
NPERS="Number of Persons in Household"
HHID="Unique 14 digit household identification code"
GEOUNIT1="Dominio*10 + Rural - 12 codes"
GEOUNIT2="Region*10 + Rural - 6 codes"
PROVINCE="Province Code"
FOODCD="Food Code in 1998 Questionnaire"
FOOD95="Food Code in 1995 Questionnaire"
RURAL="Urban 1 Rural 2"
SPEND="Spending in two weeks, NO FREQ"
SPENDING="Spending in 2 weeks, with FREQ"
TOTGRAM="Total Grams by household NO FREQ in 14 days"
GRAM="Grams per day per person, with FREQ"
CALBWTOT="Cals consumed household 2 weeks no FREQ "
CALBWTO2="Cals consumed household 2 weeks with FREQ "
PRICECAL="Price per calorie no FREQ"
PRICECA2="Price per calorie with FREQ"
WAST="Wastage factor to convert gross to net"
CALORIES="Kilocalories of food item";


PROC MEANS;
TITLE "Mean spending for FOOD item &count, Nixed&count";
PROC SORT; BY HHID;

%let count=%eval(&count+1);
%end;
%mend gastalim;

%gastalim;
RUN;

PROC PRINTTO;
RUN;
ENDSAS;
