/* ########################################################################## */
/* STEP 2 */
/* ########################################################################## */
/* ERROFIX1.SAS */
/* ########################################################################## */
/* ########################################################################## */
/* Fixes the errors of missing and extreme values with mean values */

/* Overall, 1 percent of the cases needed fixing in this way */

/* Written by Suhas D. Parandekar, June 17, 1999 */
/* Last updated by Suhas D. Parandekar, January 3, 2000 */

/* ########################################################################## */

/* INPUT DATA - FOOD1 to FOOD85 (Raw Consumption Expenditure
   in a format which permits aggregation across food items, generated by
   the program FOODCODE.SAS ) */

/* OUTPUT DATA - 85 separate data sets, called FIXED1 to FIXED86
                 which are the amended version of the 85 original
                 datasets, FOOD1 to FOOD85 */

/* OUTPUT OF DESCRIPTIVES - ERROFIX1.LST  provides means      */

/* ########################################################################## */

OPTIONS COMPRESS=YES LS=72 NOCENTER PAGENO=1;
LIBNAME SASDATA 'P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\data\newdata\sas';

/* Specify Destination location for log and output (.lst) file */

PROC PRINTTO LOG='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\ErroFix1.LOG'
             PRINT='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\ErroFix1.LST';


/* a macro to fix errors */

%macro fixit;
%let count=1;
%do %while(&count<86);
%put the value of count is &count;

DATA FOOD&count;
SET SASDATA.FOOD&count;
FORMAT HHID 14.;
/* PURCHASED ITEMS */

/* Identify missing frequency values */

E1_21=0;
IF PURCHASE=1 AND FREQ = . THEN E1_21=1;
IF PURCHASE=1 AND FREQ = 0 THEN E1_21=1;

/* Later impute mean frequencies */


E1_12=0;
IF PURCHASE=2 AND FREQ GE 1 AND FREQ LE 7 THEN E1_12=1;

/* Fix error E1_12 */
IF E1_12=1 THEN PURCHASE=1;


/* Identify missing quantity purchased values */

E2_21=0;
IF PURCHASE=1 AND QUANTPUR = . THEN E2_21=1;
IF PURCHASE=1 AND QUANTPUR = 0 THEN E2_21=1;


/* Later, impute mean quantities */

E2_12=0;
IF PURCHASE=2 AND QUANTPUR GT 0 THEN E2_12=1;

/* Fix error E2_12 */
IF E2_12=1 THEN PURCHASE=1;


/* Identify extreme quantity purchased values */
/* Calculate grams per per person per day - If this is more than
   500 grams then flag as possible error */

/* Daily */
IF UNIT = 1 AND FREQ = 1 THEN GRAMS=QUANTPUR;
IF UNIT = 2 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 3 AND FREQ = 1 THEN GRAMS=28.35*QUANTPUR;
IF UNIT = 4 AND FREQ = 1 THEN GRAMS=453.6*QUANTPUR;
IF UNIT = 5 AND FREQ = 1 THEN GRAMS=(453.6)*(25)*(QUANTPUR);
IF UNIT = 6 AND FREQ = 1 THEN GRAMS=45351.4*QUANTPUR;
IF UNIT = 7 AND FREQ = 1 THEN GRAMS=QUANTPUR; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 9 AND FREQ = 1 THEN GRAMS=3785.41*QUANTPUR;

/* Weekly */

IF UNIT = 1 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7;
IF UNIT = 2 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 3 AND FREQ = 2 THEN GRAMS=(28.35*QUANTPUR)/7;
IF UNIT = 4 AND FREQ = 2 THEN GRAMS=(453.6*QUANTPUR)/7;
IF UNIT = 5 AND FREQ = 2 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/7;
IF UNIT = 6 AND FREQ = 2 THEN GRAMS=(45351.4*QUANTPUR)/7;
IF UNIT = 7 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 9 AND FREQ = 2 THEN GRAMS=(3785.41*QUANTPUR)/7;

/* Fortnightly */

IF UNIT = 1 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14;
IF UNIT = 2 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 3 AND FREQ = 3 THEN GRAMS=(28.35*QUANTPUR)/14;
IF UNIT = 4 AND FREQ = 3 THEN GRAMS=(453.6*QUANTPUR)/14;
IF UNIT = 5 AND FREQ = 3 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/14;
IF UNIT = 6 AND FREQ = 3 THEN GRAMS=(45351.4*QUANTPUR)/14;
IF UNIT = 7 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 9 AND FREQ = 3 THEN GRAMS=(3785.41*QUANTPUR)/14;

/* Monthly */

IF UNIT = 1 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30;
IF UNIT = 2 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 3 AND FREQ = 4 THEN GRAMS=(28.35*QUANTPUR)/30;
IF UNIT = 4 AND FREQ = 4 THEN GRAMS=(453.6*QUANTPUR)/30;
IF UNIT = 5 AND FREQ = 4 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/30;
IF UNIT = 6 AND FREQ = 4 THEN GRAMS=(45351.4*QUANTPUR)/30;
IF UNIT = 7 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 9 AND FREQ = 4 THEN GRAMS=(3785.41*QUANTPUR)/30;

/* Three-Monthly */

IF UNIT = 1 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92;
IF UNIT = 2 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 4 AND FREQ = 5 THEN GRAMS=(453.6*QUANTPUR)/92;
IF UNIT = 5 AND FREQ = 5 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/92;
IF UNIT = 6 AND FREQ = 5 THEN GRAMS=(45351.4*QUANTPUR)/92;
IF UNIT = 7 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 9 AND FREQ = 5 THEN GRAMS=(3785.41*QUANTPUR)/92;

/* Six-Monthly */

IF UNIT = 1 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183;
IF UNIT = 2 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 3 AND FREQ = 6 THEN GRAMS=(28.35*QUANTPUR)/183;
IF UNIT = 4 AND FREQ = 6 THEN GRAMS=(453.6*QUANTPUR)/183;
IF UNIT = 5 AND FREQ = 6 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/183;
IF UNIT = 6 AND FREQ = 6 THEN GRAMS=(45351.4*QUANTPUR)/183;
IF UNIT = 7 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 9 AND FREQ = 6 THEN GRAMS=(3785.41*QUANTPUR)/183;

/* Yearly */

IF UNIT = 1 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366;
IF UNIT = 2 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 3 AND FREQ = 7 THEN GRAMS=(28.35*QUANTPUR)/366;
IF UNIT = 4 AND FREQ = 7 THEN GRAMS=(453.6*QUANTPUR)/366;
IF UNIT = 5 AND FREQ = 7 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/366;
IF UNIT = 6 AND FREQ = 7 THEN GRAMS=(45351.4*QUANTPUR)/366;
IF UNIT = 7 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 9 AND FREQ = 7 THEN GRAMS=(3785.41*QUANTPUR)/366;


IF NPERS GT 0 THEN GRAMPER=GRAMS/NPERS;

BIGEAT=0;
IF GRAMPER GT 500 THEN BIGEAT=1;

/* Identify missing expenditure values */

E3_21=0;
if purchase=1 and expend=. THEN E3_21=1;
if purchase=1 and expend=0 THEN E3_21=1;

/* Later, impute mean values */

E3_12=0;
if purchase=2 and EXPEND GT 0 THEN E3_12=1;

/* Fix error E3_12 */

IF E3_12=1 THEN PURCHASE=1;


/* NON-PURCHASED ITEMS */

/* Identify missing frequency values */

Z1_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = . THEN Z1_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = 0 THEN Z1_21=1;

/* Later, impute mean values */

Z1_12=0;
IF NONPUR = . AND FREQNPUR GE 0 THEN Z1_12=1;

/* Fix error Z1_12 */

IF Z1_12 = 1 THEN NONPUR=1;

/* Identify missing quantity purchased values */

Z2_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = . THEN Z2_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = 0 THEN Z2_21=1;

/* Later, impute mean values */

Z2_12=0;
IF NONPUR = . AND QUANNPUR GT 0 THEN Z2_12=1;

/* Fix error Z2_12 */

IF Z2_12=1 THEN NONPUR=1;

/* Identify extreme quantity non-purchased values */
/* Calculate grams per per person per day - If this is more than
   500 grams then flag as error */

/* Daily */
IF UNITNPUR = 1 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR;
IF UNITNPUR = 2 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 3 AND FREQNPUR = 1 THEN GRAMSN=28.35*QUANNPUR;
IF UNITNPUR = 4 AND FREQNPUR = 1 THEN GRAMSN=453.6*QUANNPUR;
IF UNITNPUR = 5 AND FREQNPUR = 1 THEN GRAMSN=(453.6)*(25)*(QUANNPUR);
IF UNITNPUR = 6 AND FREQNPUR = 1 THEN GRAMSN=45351.4*QUANNPUR;
IF UNITNPUR = 7 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 9 AND FREQNPUR = 1 THEN GRAMSN=3785.41*QUANNPUR;

/* Weekly */

IF UNITNPUR = 1 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7;
IF UNITNPUR = 2 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 3 AND FREQNPUR = 2 THEN GRAMSN=(28.35*QUANNPUR)/7;
IF UNITNPUR = 4 AND FREQNPUR = 2 THEN GRAMSN=(453.6*QUANNPUR)/7;
IF UNITNPUR = 5 AND FREQNPUR = 2 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/7;
IF UNITNPUR = 6 AND FREQNPUR = 2 THEN GRAMSN=(45351.4*QUANNPUR)/7;
IF UNITNPUR = 7 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 9 AND FREQNPUR = 2 THEN GRAMSN=(3785.41*QUANNPUR)/7;

/* Fortnightly */

IF UNITNPUR = 1 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14;
IF UNITNPUR = 2 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 3 AND FREQNPUR = 3 THEN GRAMSN=(28.35*QUANNPUR)/14;
IF UNITNPUR = 4 AND FREQNPUR = 3 THEN GRAMSN=(453.6*QUANNPUR)/14;
IF UNITNPUR = 5 AND FREQNPUR = 3 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/14;
IF UNITNPUR = 6 AND FREQNPUR = 3 THEN GRAMSN=(45351.4*QUANNPUR)/14;
IF UNITNPUR = 7 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 9 AND FREQNPUR = 3 THEN GRAMSN=(3785.41*QUANNPUR)/14;

/* Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30;
IF UNITNPUR = 2 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 3 AND FREQNPUR = 4 THEN GRAMSN=(28.35*QUANNPUR)/30;
IF UNITNPUR = 4 AND FREQNPUR = 4 THEN GRAMSN=(453.6*QUANNPUR)/30;
IF UNITNPUR = 5 AND FREQNPUR = 4 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/30;
IF UNITNPUR = 6 AND FREQNPUR = 4 THEN GRAMSN=(45351.4*QUANNPUR)/30;
IF UNITNPUR = 7 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 9 AND FREQNPUR = 4 THEN GRAMSN=(3785.41*QUANNPUR)/30;

/* Three-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92;
IF UNITNPUR = 2 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 3 AND FREQNPUR = 5 THEN GRAMSN=(28.35*QUANNPUR)/92;
IF UNITNPUR = 4 AND FREQNPUR = 5 THEN GRAMSN=(453.6*QUANNPUR)/92;
IF UNITNPUR = 5 AND FREQNPUR = 5 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/92;
IF UNITNPUR = 6 AND FREQNPUR = 5 THEN GRAMSN=(45351.4*QUANNPUR)/92;
IF UNITNPUR = 7 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 9 AND FREQNPUR = 5 THEN GRAMSN=(3785.41*QUANNPUR)/92;

/* Six-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183;
IF UNITNPUR = 2 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 3 AND FREQNPUR = 6 THEN GRAMSN=(28.35*QUANNPUR)/183;
IF UNITNPUR = 4 AND FREQNPUR = 6 THEN GRAMSN=(453.6*QUANNPUR)/183;
IF UNITNPUR = 5 AND FREQNPUR = 6 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/183;
IF UNITNPUR = 6 AND FREQNPUR = 6 THEN GRAMSN=(45351.4*QUANNPUR)/183;
IF UNITNPUR = 7 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 9 AND FREQNPUR = 6 THEN GRAMSN=(3785.41*QUANNPUR)/183;

/* Yearly */

IF UNITNPUR = 1 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366;
IF UNITNPUR = 2 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 3 AND FREQNPUR = 7 THEN GRAMSN=(28.35*QUANNPUR)/366;
IF UNITNPUR = 4 AND FREQNPUR = 7 THEN GRAMSN=(453.6*QUANNPUR)/366;
IF UNITNPUR = 5 AND FREQNPUR = 7 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/366;
IF UNITNPUR = 6 AND FREQNPUR = 7 THEN GRAMSN=(45351.4*QUANNPUR)/366;
IF UNITNPUR = 7 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 9 AND FREQNPUR = 7 THEN GRAMSN=(3785.41*QUANNPUR)/366;

IF NPERS GT 0 THEN GRAMNPER=GRAMSN/NPERS;

BIGGET=0;
IF GRAMNPER GT 500 THEN BIGGET=1;


/* Identify missing expenditure values */
Z3_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = . THEN Z3_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = 0 THEN Z3_21=1;

/* Later, replace with mean values */

Z3_12=0;
IF NONPUR = . AND EXPENPUR GT 0 THEN Z3_12=1;
IF NONPUR = 0 AND EXPENPUR GT 0 THEN Z3_12=1; /* just 1 value */

/* Fix error Z3_12 */

IF Z3_12=1 THEN NONPUR=1;

/* Identify big eaters */

IF BIGGET = . AND BIGEAT NE . THEN BIGEAT=BIGEAT;
IF BIGGET NE . AND BIGEAT = . THEN BIGEAT=BIGGET;
IF BIGGET NE . AND BIGEAT NE . THEN BIGEAT=BIGGET+BIGEAT;

IF GRAMNPER = . AND GRAMPER NE . THEN GRAMPER=GRAMPER;
IF GRAMNPER NE . AND GRAMPER = . THEN GRAMPER=GRAMNPER;
IF GRAMNPER NE . AND GRAMPER NE . THEN GRAMPER=GRAMNPER+GRAMPER;

/* Define grams consumed per person of item in 14 days */

GRAM14=GRAMPER*14;
GRAMN14=GRAMPER*14;
/* Recover Dominio for use */
DOMINIO=INT(GEOUNIT1/10);

/* Now imputing mean values for problems */

/* For missing frequency E1_21, Z1_21 put mean frequency,quantity,expenditures */
/* For missing quantity E2_21, Z2_21, put mean quantity,frequency,expenditures */
/* For missing expenditures E3_21, Z3_21, put mean expenditures,quantity,frequency */
/* For big eaters, put mean frequency, quantity, expenditures */
/* 10 out of 20,000 odd items had missing units - these are ignored */

/* ******************************************************************* */
/* Begin imputation process */
/* ******************************************************************* */

PROC SORT DATA=FOOD&count;BY GEOUNIT1;
PROC MEANS NOPRINT ;
VAR  FREQ QUANTPUR EXPEND FREQNPUR QUANNPUR EXPENPUR;BY GEOUNIT1;
ID HHID FOODCD;
OUTPUT OUT=SASDATA.MEAN1&count
MEAN=X1_1BAR X2_1BAR X3_1BAR X4_1BAR X5_1BAR X6_1BAR;

PROC SORT DATA=FOOD&count;BY DOMINIO;
PROC MEANS NOPRINT;
VAR  FREQ QUANTPUR EXPEND FREQNPUR QUANNPUR EXPENPUR;BY DOMINIO;
ID HHID FOODCD;
OUTPUT OUT=SASDATA.MEAN2&count
MEAN=X1_2BAR X2_2BAR X3_2BAR X4_2BAR X5_2BAR X6_2BAR;

PROC SORT DATA=FOOD&count;BY GEOUNIT1;
PROC MEANS NOPRINT;
VAR  FREQ QUANTPUR EXPEND FREQNPUR QUANNPUR EXPENPUR;
ID HHID FOODCD;
OUTPUT OUT=SASDATA.MEAN3&count
MEAN=X1_3BAR X2_3BAR X3_3BAR X4_3BAR X5_3BAR X6_3BAR;

DATA SASDATA.ZERO;
SET FOOD&count;
PROC SORT; BY HHID;

DATA SASDATA.ONEa
(KEEP = HHID X1_1BAR X2_1BAR X3_1BAR X4_1BAR X5_1BAR X6_1BAR FOODCD);
SET SASDATA.MEAN1&count;
PROC SORT;BY HHID;
DATA SASDATA.ONEb
(KEEP = HHID X1_2BAR X2_2BAR X3_2BAR X4_2BAR X5_2BAR X6_2BAR FOODCD);
SET SASDATA.MEAN2&count;
PROC SORT;BY HHID;
DATA SASDATA.ONEc
(KEEP = HHID X1_3BAR X2_3BAR X3_3BAR X4_3BAR X5_3BAR X6_3BAR FOODCD);
SET SASDATA.MEAN3&count;
PROC SORT;BY HHID;


DATA SASDATA.MERa;
MERGE SASDATA.ZERO SASDATA.ONEa SASDATA.ONEb SASDATA.ONEc; BY HHID;


/* Missing Frequency values */

IF E1_21=1 THEN FREQ    =X1_1BAR;          /* Geounit1 average */
IF E1_21=1 THEN QUANTPUR=X2_1BAR;          /* Geounit1 average */
IF E1_21=1 THEN EXPEN   =X3_1BAR;          /* Geounit1 average */
IF Z1_21=1 THEN FREQNPUR    =X4_1BAR;          /* Geounit1 average */
IF Z1_21=1 THEN QUANNPUR    =X5_1BAR;          /* Geounit1 average */
IF Z1_21=1 THEN EXPENPUR    =X6_1BAR;          /* Geounit1 average */

/* Still missing then Dominio average */

E1_21=0;
IF PURCHASE=1 AND FREQ = . THEN E1_21=1;
IF PURCHASE=1 AND FREQ = 0 THEN E1_21=1;
Z1_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = . THEN Z1_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = 0 THEN Z1_21=1;


IF E1_21=1 THEN FREQ    =X1_2BAR;          /* Dominio  average */
IF E1_21=1 THEN QUANTPUR=X2_2BAR;          /* Dominio  average */
IF E1_21=1 THEN EXPEN   =X3_2BAR;          /* Dominio  average */
IF Z1_21=1 THEN FREQNPUR    =X4_2BAR;          /* Dominio  average */
IF Z1_21=1 THEN QUANNPUR    =X5_2BAR;          /* Dominio  average */
IF Z1_21=1 THEN EXPENPUR    =X6_2BAR;          /* Dominio  average */

/* Still missing then national average */

E1_21=0;
IF PURCHASE=1 AND FREQ = . THEN E1_21=1;
IF PURCHASE=1 AND FREQ = 0 THEN E1_21=1;
Z1_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = . THEN Z1_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND FREQNPUR = 0 THEN Z1_21=1;

IF E1_21=1 THEN FREQ    =X1_3BAR;          /* National average */
IF E1_21=1 THEN QUANTPUR=X2_3BAR;          /* National average */
IF E1_21=1 THEN EXPEN   =X3_3BAR;          /* National average */
IF Z1_21=1 THEN FREQNPUR    =X4_3BAR;          /* National average */
IF Z1_21=1 THEN QUANNPUR    =X5_3BAR;          /* National average */
IF Z1_21=1 THEN EXPENPUR    =X6_3BAR;          /* National average */

/* Missing Quantity  values */


IF E2_21=1 THEN FREQ    =X1_1BAR;          /* Geounit1 average */
IF E2_21=1 THEN QUANTPUR=X2_1BAR;          /* Geounit1 average */
IF E2_21=1 THEN EXPEN   =X3_1BAR;          /* Geounit1 average */
IF Z2_21=1 THEN FREQNPUR    =X4_1BAR;          /* Geounit1 average */
IF Z2_21=1 THEN QUANNPUR    =X5_1BAR;          /* Geounit1 average */
IF Z2_21=1 THEN EXPENPUR    =X6_1BAR;          /* Geounit1 average */

E2_21=0;
IF PURCHASE=1 AND QUANTPUR = . THEN E2_21=1;
IF PURCHASE=1 AND QUANTPUR = 0 THEN E2_21=1;
Z2_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = . THEN Z2_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = 0 THEN Z2_21=1;

IF E2_21=1 THEN FREQ    =X1_2BAR;          /* Dominio  average */
IF E2_21=1 THEN QUANTPUR=X2_2BAR;          /* Dominio  average */
IF E2_21=1 THEN EXPEN   =X3_2BAR;          /* Dominio  average */
IF Z2_21=1 THEN FREQNPUR    =X4_2BAR;          /* Dominio  average */
IF Z2_21=1 THEN QUANNPUR    =X5_2BAR;          /* Dominio  average */
IF Z2_21=1 THEN EXPENPUR    =X6_2BAR;          /* Dominio  average */

E2_21=0;
IF PURCHASE=1 AND QUANTPUR = . THEN E2_21=1;
IF PURCHASE=1 AND QUANTPUR = 0 THEN E2_21=1;
Z2_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = . THEN Z2_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND QUANNPUR = 0 THEN Z2_21=1;

IF E2_21=1 THEN FREQ    =X1_3BAR;          /* National average */
IF E2_21=1 THEN QUANTPUR=X2_3BAR;          /* National average */
IF E2_21=1 THEN EXPEN   =X3_3BAR;          /* National average */
IF Z2_21=1 THEN FREQNPUR    =X4_3BAR;          /* National average */
IF Z2_21=1 THEN QUANNPUR    =X5_3BAR;          /* National average */
IF Z2_21=1 THEN EXPENPUR    =X6_3BAR;          /* National average */

/* Missing Expenditure  values */

IF E3_21=1 THEN FREQ    =X1_1BAR;          /* Geounit1 average */
IF E3_21=1 THEN QUANTPUR=X2_1BAR;          /* Geounit1 average */
IF E3_21=1 THEN EXPEN   =X3_1BAR;          /* Geounit1 average */
IF Z3_21=1 THEN FREQNPUR    =X4_1BAR;          /* Geounit1 average */
IF Z3_21=1 THEN QUANNPUR    =X5_1BAR;          /* Geounit1 average */
IF Z3_21=1 THEN EXPENPUR    =X6_1BAR;          /* Geounit1 average */

E3_21=0;
if purchase=1 and expend=. THEN E3_21=1;
if purchase=1 and expend=0 THEN E3_21=1;
Z3_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = . THEN Z3_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = 0 THEN Z3_21=1;

IF E3_21=1 THEN FREQ    =X1_2BAR;          /* Dominio  average */
IF E3_21=1 THEN QUANTPUR=X2_2BAR;          /* Dominio  average */
IF E3_21=1 THEN EXPEN   =X3_2BAR;          /* Dominio  average */
IF Z3_21=1 THEN FREQNPUR    =X4_2BAR;          /* Dominio  average */
IF Z3_21=1 THEN QUANNPUR    =X5_2BAR;          /* Dominio  average */
IF Z3_21=1 THEN EXPENPUR    =X6_2BAR;          /* Dominio  average */

E3_21=0;
if purchase=1 and expend=. THEN E3_21=1;
if purchase=1 and expend=0 THEN E3_21=1;
Z3_21=0;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = . THEN Z3_21=1;
IF NONPUR GE 1 AND NONPUR LE 5 AND EXPENPUR = 0 THEN Z3_21=1;

IF E3_21=1 THEN FREQ    =X1_3BAR;          /* National average */
IF E3_21=1 THEN QUANTPUR=X2_3BAR;          /* National average */
IF E3_21=1 THEN EXPEN   =X3_3BAR;          /* National average */
IF Z3_21=1 THEN FREQNPUR    =X4_3BAR;          /* National average */
IF Z3_21=1 THEN QUANNPUR    =X5_3BAR;          /* National average */
IF Z3_21=1 THEN EXPENPUR    =X6_3BAR;          /* National average */

/* Big Eater  values */

IF BIGEAT=1 THEN FREQ    =X1_1BAR;          /* Geounit1 average */
IF BIGEAT=1 THEN QUANTPUR=X2_1BAR;          /* Geounit1 average */
IF BIGEAT=1 THEN EXPEN   =X3_1BAR;          /* Geounit1 average */
IF BIGEAT=1 THEN FREQNPUR    =X4_1BAR;          /* Geounit1 average */
IF BIGEAT=1 THEN QUANNPUR    =X5_1BAR;          /* Geounit1 average */
IF BIGEAT=1 THEN EXPENPUR    =X6_1BAR;          /* Geounit1 average */


DUMMY1=0;
IF X1_1BAR = . THEN DUMMY1=1;
DUMMY2=0;
IF X2_1BAR = . THEN DUMMY2=1;
DUMMY3=0;
IF X3_1BAR = . THEN DUMMY3=1;
DUMMY4=0;
IF X4_1BAR = . THEN DUMMY4=1;
DUMMY5=0;
IF X5_1BAR = . THEN DUMMY5=1;
DUMMY6=0;
IF X6_1BAR = . THEN DUMMY6=1;

IF BIGEAT=1 AND DUMMY1=1 THEN FREQ    =X1_2BAR;          /* Dominio  average */
IF BIGEAT=1 AND DUMMY2=1 THEN QUANTPUR=X2_2BAR;          /* Dominio  average */
IF BIGEAT=1 AND DUMMY3=1 THEN EXPEN   =X3_2BAR;          /* Dominio  average */
IF BIGEAT=1 AND DUMMY4=1 THEN FREQNPUR    =X4_2BAR;          /* Dominio  average */
IF BIGEAT=1 AND DUMMY5=1 THEN QUANNPUR    =X5_2BAR;          /* Dominio  average */
IF BIGEAT=1 AND DUMMY6=1 THEN EXPENPUR    =X6_2BAR;          /* Dominio  average */

DUMMY1=0;
IF X1_2BAR = . THEN DUMMY1=1;
DUMMY2=0;
IF X2_2BAR = . THEN DUMMY2=1;
DUMMY3=0;
IF X3_2BAR = . THEN DUMMY3=1;
DUMMY4=0;
IF X4_2BAR = . THEN DUMMY4=1;
DUMMY5=0;
IF X5_2BAR = . THEN DUMMY5=1;
DUMMY6=0;
IF X6_2BAR = . THEN DUMMY6=1;


IF BIGEAT=1 AND DUMMY1=1  THEN FREQ    =X1_3BAR;          /* National average */
IF BIGEAT=1 AND DUMMY1=1 THEN QUANTPUR=X2_3BAR;          /* National average */
IF BIGEAT=1 AND DUMMY1=1 THEN EXPEN   =X3_3BAR;          /* National average */
IF BIGEAT=1 AND DUMMY1=1 THEN FREQNPUR    =X4_3BAR;          /* National average */
IF BIGEAT=1 AND DUMMY1=1 THEN QUANNPUR    =X5_3BAR;          /* National average */
IF BIGEAT=1 AND DUMMY1=1 THEN EXPENPUR    =X6_3BAR;          /* National average */

/* Tag imputations */
IMPUTE=0;
IF E1_21=1 THEN IMPUTE=1;
IF E2_21=1 THEN IMPUTE=1;
IF E3_21=1 THEN IMPUTE=1;
IF Z1_21=1 THEN IMPUTE=1;
IF Z2_21=1 THEN IMPUTE=1;
IF Z3_21=1 THEN IMPUTE=1;
IF BIGEAT=1 THEN IMPUTE=1;

/* ******************************************************************* */
/* End imputation process */
/* ******************************************************************* */


DATA SASDATA.FIXED&count ;SET SASDATA.MERa ;
FORMAT HHID 14.;
  KEEP
  REGION AREA GEOUNIT1 GEOUNIT2 DOMINIO REGION AREA CIUDAD PROVINCE HHID NPERS FOODCD
  PURCHASE
  FREQ
  QUANTPUR
  UNIT
  EXPEND
  NONPUR
  FREQNPUR
  QUANNPUR
  UNITNPUR
  EXPENPUR IMPUTE;
PROC MEANS;
TITLE "Mean spending for FOOD item &count, corrected";
PROC SORT; BY HHID;



%let count=%eval(&count+1);
%end;
%mend fixit;

%fixit;
RUN;

/* Fixed is the file we will use */

PROC PRINTTO;
RUN;
ENDSAS;
