/* ########################################################################## */
/* STEP 4 */
/* ########################################################################## */
/* FINFOOD.SAS */
/* ########################################################################## */
/* ########################################################################## */
/* Now combine the FIXED FOOD files to get total expenditure */

/* Written by Suhas D. Parandekar, June 17, 1999 */
/* Last updated by Suhas D. Parandekar, January 3, 2000 */

/* ########################################################################## */

/* INPUT DATA - FIXED1 to FIXED84 (Consumption Expenditure,
   corrected for extreme values and miscodings, generated by the program ERROFIX1.SAS )
   also, a file called FOODIMP2.POR, provided by SIISE of Ecuador, which
   provides calorific values for the food items */

/* OUTPUT DATA - Merged file FINFOOD2 - Total Food Expenditure for household */

/* OUTPUT OF DESCRIPTIVES - FINFOOD.LST  provides means and a list of
   household IDS for 108 households which reported zero total food expenses
   - the questionnaires were manually examined at the INEC offices in Quito,
   and the 108, the zero food expenses are not miscodings - they represent
   households where no food was prepared in the past month, so there were not
   any expenses on the items in the questionnaire */  */

/* ########################################################################## */
OPTIONS COMPRESS=YES LS=72 NOCENTER PAGENO=1;
LIBNAME SASDATA 'P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\data\newdata\sas';
PROC PRINTTO
  LOG='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\FINFOOD.LOG'
  PRINT='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\FINFOOD.LST';


%macro gastalim;
%let count=1;
%do %while(&count<85);
%put the value of count is &count;
DATA JUNK&count;
SET SASDATA.FIXED&count;

/* Consumption in grams */
/* Daily */
IF UNIT = 1 AND FREQ = 1 THEN GRAMS=QUANTPUR;
IF UNIT = 2 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 3 AND FREQ = 1 THEN GRAMS=28.35*QUANTPUR;
IF UNIT = 4 AND FREQ = 1 THEN GRAMS=453.6*QUANTPUR;
IF UNIT = 5 AND FREQ = 1 THEN GRAMS=(453.6)*(25)*(QUANTPUR);
IF UNIT = 6 AND FREQ = 1 THEN GRAMS=45351.47*QUANTPUR;
IF UNIT = 7 AND FREQ = 1 THEN GRAMS=QUANTPUR; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 1 THEN GRAMS=1000*QUANTPUR;
IF UNIT = 9 AND FREQ = 1 THEN GRAMS=3785.41*QUANTPUR;

/* Weekly */

IF UNIT = 1 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7;
IF UNIT = 2 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 3 AND FREQ = 2 THEN GRAMS=(28.35*QUANTPUR)/7;
IF UNIT = 4 AND FREQ = 2 THEN GRAMS=(453.6*QUANTPUR)/7;
IF UNIT = 5 AND FREQ = 2 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/7;
IF UNIT = 6 AND FREQ = 2 THEN GRAMS=(45351.47*QUANTPUR)/7;
IF UNIT = 7 AND FREQ = 2 THEN GRAMS=(QUANTPUR)/7; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 2 THEN GRAMS=(1000*QUANTPUR)/7;
IF UNIT = 9 AND FREQ = 2 THEN GRAMS=(3785.41*QUANTPUR)/7;

/* Fortnightly */

IF UNIT = 1 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14;
IF UNIT = 2 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 3 AND FREQ = 3 THEN GRAMS=(28.35*QUANTPUR)/14;
IF UNIT = 4 AND FREQ = 3 THEN GRAMS=(453.6*QUANTPUR)/14;
IF UNIT = 5 AND FREQ = 3 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/14;
IF UNIT = 6 AND FREQ = 3 THEN GRAMS=(45351.47*QUANTPUR)/14;
IF UNIT = 7 AND FREQ = 3 THEN GRAMS=(QUANTPUR)/14; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 3 THEN GRAMS=(1000*QUANTPUR)/14;
IF UNIT = 9 AND FREQ = 3 THEN GRAMS=(3785.41*QUANTPUR)/14;

/* Monthly */

IF UNIT = 1 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30;
IF UNIT = 2 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 3 AND FREQ = 4 THEN GRAMS=(28.35*QUANTPUR)/30;
IF UNIT = 4 AND FREQ = 4 THEN GRAMS=(453.6*QUANTPUR)/30;
IF UNIT = 5 AND FREQ = 4 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/30;
IF UNIT = 6 AND FREQ = 4 THEN GRAMS=(45351.47*QUANTPUR)/30;
IF UNIT = 7 AND FREQ = 4 THEN GRAMS=(QUANTPUR)/30; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 4 THEN GRAMS=(1000*QUANTPUR)/30;
IF UNIT = 9 AND FREQ = 4 THEN GRAMS=(3785.41*QUANTPUR)/30;

/* Three-Monthly */

IF UNIT = 1 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92;
IF UNIT = 2 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 3 AND FREQ = 5 THEN GRAMS=(28.35*QUANTPUR)/92;
IF UNIT = 4 AND FREQ = 5 THEN GRAMS=(453.6*QUANTPUR)/92;
IF UNIT = 5 AND FREQ = 5 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/92;
IF UNIT = 6 AND FREQ = 5 THEN GRAMS=(45351.47*QUANTPUR)/92;
IF UNIT = 7 AND FREQ = 5 THEN GRAMS=(QUANTPUR)/92; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 5 THEN GRAMS=(1000*QUANTPUR)/92;
IF UNIT = 9 AND FREQ = 5 THEN GRAMS=(3785.41*QUANTPUR)/92;

/* Six-Monthly */

IF UNIT = 1 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183;
IF UNIT = 2 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 3 AND FREQ = 6 THEN GRAMS=(28.35*QUANTPUR)/183;
IF UNIT = 4 AND FREQ = 6 THEN GRAMS=(453.6*QUANTPUR)/183;
IF UNIT = 5 AND FREQ = 6 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/183;
IF UNIT = 6 AND FREQ = 6 THEN GRAMS=(45351.47*QUANTPUR)/183;
IF UNIT = 7 AND FREQ = 6 THEN GRAMS=(QUANTPUR)/183; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 6 THEN GRAMS=(1000*QUANTPUR)/183;
IF UNIT = 9 AND FREQ = 6 THEN GRAMS=(3785.41*QUANTPUR)/183;

/* Yearly */

IF UNIT = 1 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366;
IF UNIT = 2 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 3 AND FREQ = 7 THEN GRAMS=(28.35*QUANTPUR)/366;
IF UNIT = 4 AND FREQ = 7 THEN GRAMS=(453.6*QUANTPUR)/366;
IF UNIT = 5 AND FREQ = 7 THEN GRAMS=((453.6)*(25)*(QUANTPUR))/366;
IF UNIT = 6 AND FREQ = 7 THEN GRAMS=(45351.47*QUANTPUR)/366;
IF UNIT = 7 AND FREQ = 7 THEN GRAMS=(QUANTPUR)/366; /* Pretend density is 1 */
IF UNIT = 8 AND FREQ = 7 THEN GRAMS=(1000*QUANTPUR)/366;
IF UNIT = 9 AND FREQ = 7 THEN GRAMS=(3785.41*QUANTPUR)/366;


IF NPERS GT 0 THEN GRAMPER=GRAMS/NPERS;
/* ************************************************* */

/* NON-PURCHASED ITEMS */

/* Daily */
IF UNITNPUR = 1 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR;
IF UNITNPUR = 2 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 3 AND FREQNPUR = 1 THEN GRAMSN=28.35*QUANNPUR;
IF UNITNPUR = 4 AND FREQNPUR = 1 THEN GRAMSN=453.6*QUANNPUR;
IF UNITNPUR = 5 AND FREQNPUR = 1 THEN GRAMSN=(453.6)*(25)*(QUANNPUR);
IF UNITNPUR = 6 AND FREQNPUR = 1 THEN GRAMSN=45351.47*QUANNPUR;
IF UNITNPUR = 7 AND FREQNPUR = 1 THEN GRAMSN=QUANNPUR; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 1 THEN GRAMSN=1000*QUANNPUR;
IF UNITNPUR = 9 AND FREQNPUR = 1 THEN GRAMSN=3785.41*QUANNPUR;

/* Weekly */

IF UNITNPUR = 1 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7;
IF UNITNPUR = 2 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 3 AND FREQNPUR = 2 THEN GRAMSN=(28.35*QUANNPUR)/7;
IF UNITNPUR = 4 AND FREQNPUR = 2 THEN GRAMSN=(453.6*QUANNPUR)/7;
IF UNITNPUR = 5 AND FREQNPUR = 2 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/7;
IF UNITNPUR = 6 AND FREQNPUR = 2 THEN GRAMSN=(45351.47*QUANNPUR)/7;
IF UNITNPUR = 7 AND FREQNPUR = 2 THEN GRAMSN=(QUANNPUR)/7; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 2 THEN GRAMSN=(1000*QUANNPUR)/7;
IF UNITNPUR = 9 AND FREQNPUR = 2 THEN GRAMSN=(3785.41*QUANNPUR)/7;

/* Fortnightly */

IF UNITNPUR = 1 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14;
IF UNITNPUR = 2 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 3 AND FREQNPUR = 3 THEN GRAMSN=(28.35*QUANNPUR)/14;
IF UNITNPUR = 4 AND FREQNPUR = 3 THEN GRAMSN=(453.6*QUANNPUR)/14;
IF UNITNPUR = 5 AND FREQNPUR = 3 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/14;
IF UNITNPUR = 6 AND FREQNPUR = 3 THEN GRAMSN=(45351.47*QUANNPUR)/14;
IF UNITNPUR = 7 AND FREQNPUR = 3 THEN GRAMSN=(QUANNPUR)/14; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 3 THEN GRAMSN=(1000*QUANNPUR)/14;
IF UNITNPUR = 9 AND FREQNPUR = 3 THEN GRAMSN=(3785.41*QUANNPUR)/14;

/* Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30;
IF UNITNPUR = 2 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 3 AND FREQNPUR = 4 THEN GRAMSN=(28.35*QUANNPUR)/30;
IF UNITNPUR = 4 AND FREQNPUR = 4 THEN GRAMSN=(453.6*QUANNPUR)/30;
IF UNITNPUR = 5 AND FREQNPUR = 4 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/30;
IF UNITNPUR = 6 AND FREQNPUR = 4 THEN GRAMSN=(45351.47*QUANNPUR)/30;
IF UNITNPUR = 7 AND FREQNPUR = 4 THEN GRAMSN=(QUANNPUR)/30; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 4 THEN GRAMSN=(1000*QUANNPUR)/30;
IF UNITNPUR = 9 AND FREQNPUR = 4 THEN GRAMSN=(3785.41*QUANNPUR)/30;

/* Three-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92;
IF UNITNPUR = 2 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 3 AND FREQNPUR = 5 THEN GRAMSN=(28.35*QUANNPUR)/92;
IF UNITNPUR = 4 AND FREQNPUR = 5 THEN GRAMSN=(453.6*QUANNPUR)/92;
IF UNITNPUR = 5 AND FREQNPUR = 5 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/92;
IF UNITNPUR = 6 AND FREQNPUR = 5 THEN GRAMSN=(45351.47*QUANNPUR)/92;
IF UNITNPUR = 7 AND FREQNPUR = 5 THEN GRAMSN=(QUANNPUR)/92; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 5 THEN GRAMSN=(1000*QUANNPUR)/92;
IF UNITNPUR = 9 AND FREQNPUR = 5 THEN GRAMSN=(3785.41*QUANNPUR)/92;

/* Six-Monthly */

IF UNITNPUR = 1 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183;
IF UNITNPUR = 2 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 3 AND FREQNPUR = 6 THEN GRAMSN=(28.35*QUANNPUR)/183;
IF UNITNPUR = 4 AND FREQNPUR = 6 THEN GRAMSN=(453.6*QUANNPUR)/183;
IF UNITNPUR = 5 AND FREQNPUR = 6 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/183;
IF UNITNPUR = 6 AND FREQNPUR = 6 THEN GRAMSN=(45351.47*QUANNPUR)/183;
IF UNITNPUR = 7 AND FREQNPUR = 6 THEN GRAMSN=(QUANNPUR)/183; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 6 THEN GRAMSN=(1000*QUANNPUR)/183;
IF UNITNPUR = 9 AND FREQNPUR = 6 THEN GRAMSN=(3785.41*QUANNPUR)/183;

/* Yearly */

IF UNITNPUR = 1 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366;
IF UNITNPUR = 2 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 3 AND FREQNPUR = 7 THEN GRAMSN=(28.35*QUANNPUR)/366;
IF UNITNPUR = 4 AND FREQNPUR = 7 THEN GRAMSN=(453.6*QUANNPUR)/366;
IF UNITNPUR = 5 AND FREQNPUR = 7 THEN GRAMSN=((453.6)*(25)*(QUANNPUR))/366;
IF UNITNPUR = 6 AND FREQNPUR = 7 THEN GRAMSN=(45351.47*QUANNPUR)/366;
IF UNITNPUR = 7 AND FREQNPUR = 7 THEN GRAMSN=(QUANNPUR)/366; /* Pretend density is 1 */
IF UNITNPUR = 8 AND FREQNPUR = 7 THEN GRAMSN=(1000*QUANNPUR)/366;
IF UNITNPUR = 9 AND FREQNPUR = 7 THEN GRAMSN=(3785.41*QUANNPUR)/366;

IF NPERS GT 0 THEN GRAMNPER=GRAMSN/NPERS;

/* Define total grams bought or obtained by household in past 14
   days, regardless of whether they consumed it or not */
/* This variable is TOTGRAM */

IF UNIT = 1  THEN TRAMS=QUANTPUR;
IF UNIT = 2  THEN TRAMS=1000*QUANTPUR;
IF UNIT = 3  THEN TRAMS=28.35*QUANTPUR;
IF UNIT = 4  THEN TRAMS=453.6*QUANTPUR;
IF UNIT = 5  THEN TRAMS=(453.6)*(25)*(QUANTPUR);
IF UNIT = 6  THEN TRAMS=45351.47*QUANTPUR;
IF UNIT = 7  THEN TRAMS=QUANTPUR; /* Pretend density is 1 */
IF UNIT = 8  THEN TRAMS=1000*QUANTPUR;
IF UNIT = 9  THEN TRAMS=3785.41*QUANTPUR;


IF UNITNPUR = 1  THEN TRAMSN=QUANNPUR;
IF UNITNPUR = 2  THEN TRAMSN=1000*QUANNPUR;
IF UNITNPUR = 3  THEN TRAMSN=28.35*QUANNPUR;
IF UNITNPUR = 4  THEN TRAMSN=453.6*QUANNPUR;
IF UNITNPUR = 5  THEN TRAMSN=(453.6)*(25)*(QUANNPUR);
IF UNITNPUR = 6  THEN TRAMSN=45351.47*QUANNPUR;
IF UNITNPUR = 7  THEN TRAMSN=QUANNPUR; /* Pretend density is 1 */
IF UNITNPUR = 8  THEN TRAMSN=1000*QUANNPUR;
IF UNITNPUR = 9  THEN TRAMSN=3785.41*QUANNPUR;

IF TRAMS = . THEN TRAMS=0;
IF TRAMSN = . THEN TRAMSN=0;
IF GRAMPER = . THEN GRAMPER=0;
IF GRAMNPER = . THEN GRAMNPER=0;
IF EXPEND= . THEN EXPEND=0;
IF EXPENPUR = . THEN EXPENPUR=0;

/* Now "price" or unit value per gram */

IF TRAMS GT 0 AND EXPEND GT 0 THEN PRICE1=EXPEND/TRAMS;
IF TRAMSN GT 0 AND EXPENPUR GT 0 THEN PRICE2=EXPENPUR/TRAMSN;


/* Now spending imputed in 14 days for how many grams */

GRAM1=GRAMPER*NPERS*14;
GRAM2=GRAMNPER*NPERS*14;

/* Imputed consumption in 14 days */
SPEND1=GRAM1*PRICE1;
SPEND2=GRAM2*PRICE2;

IF SPEND1= . THEN SPEND1=0;
IF SPEND2= . THEN SPEND2=0;

SPENDING=SPEND1+SPEND2;
IF SPENDING = . THEN SPENDING=0;
KEEP HHID FOODCD SPENDING;

INFORMAT HHID 14.;
PROC SORT; BY HHID FOODCD;
%let count=%eval(&count+1);
%end;
%mend gastalim;

%gastalim;

DATA FINFOOD1;
MERGE
JUNK1  JUNK2  JUNK3  JUNK4  JUNK5  JUNK6  JUNK7  JUNK8
JUNK9  JUNK10 JUNK11 JUNK12 JUNK13 JUNK14 JUNK15 JUNK16
JUNK17 JUNK18 JUNK19 JUNK20 JUNK21 JUNK22 JUNK23 JUNK24
JUNK25 JUNK26 JUNK27 JUNK28 JUNK29 JUNK30 JUNK31 JUNK32
JUNK33 JUNK34 JUNK35 JUNK36 JUNK37 JUNK38 JUNK39 JUNK40
JUNK41 JUNK42 JUNK43 JUNK44 JUNK45 JUNK46 JUNK47 JUNK48
JUNK49 JUNK50 JUNK51 JUNK52 JUNK53 JUNK54 JUNK55 JUNK56
JUNK57 JUNK58 JUNK59 JUNK60 JUNK61 JUNK62 JUNK63 JUNK64
JUNK65 JUNK66 JUNK67 JUNK68 JUNK69 JUNK70 JUNK71 JUNK72
JUNK73 JUNK74 JUNK75 JUNK76 JUNK77 JUNK78 JUNK79 JUNK80
JUNK81 JUNK82 JUNK83 JUNK84;
BY HHID FOODCD;
INFORMAT HHID 14.;

PROC SORT; BY HHID;
PROC MEANS SUM NOPRINT;
VAR SPENDING;
BY HHID;
OUTPUT OUT=FINFOOD2 SUM=FOODEXP;

DATA FINFOO2a(DROP=_TYPE_ _FREQ_);
SET FINFOOD2;
INFORMAT HHID 14.;
PROC SORT; BY HHID;

DATA SASDATA.ALLMISS;  /* should have cases where all are missing */
SET FINFOO2a;
IF FOODEXP GT 0 THEN DELETE;
ALLMISS=1;
INFORMAT HHID 14.;
PROC MEANS;
PROC PRINT;
TITLE "Household ids with zero FOOD expenditure";
PROC SORT;BY HHID;


DATA SASDATA.FINFOOD2; MERGE FINFOO2a(IN=IN2a) SASDATA.ALLMISS(IN=IN2b);
IF IN2b THEN DELETE; /* 108 households with zero food expenditures */
INFORMAT HHID 14.;
KEEP HHID FOODEXP;
BY HHID;

PROC MEANS;
TITLE "Total Food expenditure means";
RUN;

PROC PRINTTO;
RUN;

ENDSAS;
