/* ########################################################################## */
/* STEP 1 */
/* ########################################################################## */

/* ########################################################################## */
/* FOODCODE.SAS */
/* ########################################################################## */

/* Creates common files for aggregation of food expenditures */
/* Files named SASDATA.FOOD1 to SASDATA.FOOD93 */

/* Written by Suhas D. Parandekar, June 10, 1999 */
/* Last updated by Suhas D. Parandekar, December 29, 1999 */

/* ########################################################################## */

/* INPUT DATA - E98GA10, E98GA20, E98GA30 (Raw Consumption Expenditure Data ) */

/* OUTPUT DATA - 93 separate data sets, one for each consumption item, numbered
                 1 to 93 in the ECV-III questionnaire - new data sets named as
                 FOOD1 to FOOD93 */

/* OUTPUT OF DESCRIPTIVES - FOODCODE.LST  provides means      */

/* NOTE: Items 87 through 93 are not used in the subsequent analysis -
   these are miscellaneous food items about which detailed information
   was not recorded as for the first 86 food items */


/* ########################################################################## */

OPTIONS COMPRESS=NO LS=72 SOURCE2 NOCENTER PAGENO=1;

LIBNAME SASDATA 'P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\data\newdata\sas';


/* Specify Destination location for log and output (.lst) file */

PROC PRINTTO LOG='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\Foodcode.LOG'
             PRINT='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\Foodcode.LST';


/* A sas macro which creates common variable names for each of
   the food items and saves the output with classification variables */

  %macro makefood;
   %let count=1;
     %do %while(&count<10);
     %put the value of count is &count;
  DATA SASDATA.FOOD&count ;
  SET ONEa;

/* Define the renamed variables */

  FOODCD=30&count;

/* Purchased and consumed items */

  PURCHASE = GA030&count;;
  FREQ =     GA040&count;
  QUANTPUR = GA050&count;
  UNIT =     GA050&count.A;
  IF GA060&count LT 999998 THEN EXPEND =   GA060&count;

/* Non-purchased and consumed items */

  NONPUR =   GA070&count;
  FREQNPUR = GA080&count;
  QUANNPUR = GA090&count;
  UNITNPUR = GA090&count.A;
  IF GA100&count LT 999998 THEN EXPENPUR = GA100&count;


  KEEP
  REGION AREA GEOUNIT1 GEOUNIT2 REGION AREA CIUDAD PROVINCE HHID NPERS FOODCD
  PURCHASE
  FREQ
  QUANTPUR
  UNIT
  EXPEND
  NONPUR
  FREQNPUR
  QUANNPUR
  UNITNPUR
  EXPENPUR;

  PROC MEANS;
  TITLE "MEANS FROM FOODITEM &count";
  FOOTNOTE "Suhas D. Parandekar, 3rd Round Ecuador LSMS, &sysday, &sysdate, &systime";
     %let count=%eval(&count+1);
     %end;
  %mend makefood;


  %macro makefo2a;
   %let count=10;
     %do %while(&count<32);
     %put the value of count is &count;
  DATA SASDATA.FOOD&count ;
  SET ONEa;
    FOODCD=3&count;
/* Purchased and consumed items */

  PURCHASE = GA03&count;;
  FREQ =     GA04&count;
  QUANTPUR = GA05&count;
  UNIT =     GA05&count.A;
  IF GA06&count LT 999998 THEN EXPEND =   GA06&count;

/* Non-purchased and consumed items */

  NONPUR =   GA07&count;
  FREQNPUR = GA08&count;
  QUANNPUR = GA09&count;
  UNITNPUR = GA09&count.A;
  IF GA10&count LT 999998 THEN EXPENPUR = GA10&count;


  KEEP
  REGION AREA GEOUNIT1 GEOUNIT2 REGION AREA CIUDAD PROVINCE HHID NPERS FOODCD
  PURCHASE
  FREQ
  QUANTPUR
  UNIT
  EXPEND
  NONPUR
  FREQNPUR
  QUANNPUR
  UNITNPUR
  EXPENPUR;
  PROC MEANS;
  TITLE "MEANS FROM FOODITEM &count";
  FOOTNOTE "Suhas D. Parandekar, 3rd Round Ecuador LSMS, &sysday, &sysdate, &systime";
     %let count=%eval(&count+1);
     %end;
  %mend makefo2a;



  %macro makefo2b;
   %let count=32;
     %do %while(&count<63);
     %put the value of count is &count;
  DATA SASDATA.FOOD&count ;
  SET ONEb;
    FOODCD=3&count;
/* Purchased and consumed items */

  PURCHASE = GA03&count;;
  FREQ =     GA04&count;
  QUANTPUR = GA05&count;
  UNIT =     GA05&count.A;
  IF GA06&count LT 999998 THEN EXPEND =   GA06&count;

/* Non-purchased and consumed items */

  NONPUR =   GA07&count;
  FREQNPUR = GA08&count;
  QUANNPUR = GA09&count;
  UNITNPUR = GA09&count.A;
  IF GA10&count LT 999998 THEN EXPENPUR = GA10&count;


  KEEP
  REGION AREA GEOUNIT1 GEOUNIT2 REGION AREA CIUDAD PROVINCE HHID NPERS FOODCD
  PURCHASE
  FREQ
  QUANTPUR
  UNIT
  EXPEND
  NONPUR
  FREQNPUR
  QUANNPUR
  UNITNPUR
  EXPENPUR;
  PROC MEANS;
  TITLE "MEANS FROM FOODITEM &count";
  FOOTNOTE "Suhas D. Parandekar, 3rd Round Ecuador LSMS, &sysday, &sysdate, &systime";
     %let count=%eval(&count+1);
     %end;
  %mend makefo2b;





  %macro makefoo3;
   %let count=63;
     %do %while(&count<94);
     %put the value of count is &count;
   DATA SASDATA.FOOD&count ;
   SET ONEc;

  FOODCD=3&count;

/* Purchased and consumed items */

  PURCHASE = GA03&count;;
  FREQ =     GA04&count;
  QUANTPUR = GA05&count;
  UNIT =     GA05&count.A;
  IF GA06&count LT 999998 THEN EXPEND =   GA06&count;

/* Non-purchased and consumed items */

  NONPUR =   GA07&count;
  FREQNPUR = GA08&count;
  QUANNPUR = GA09&count;
  UNITNPUR = GA09&count.A;
  IF GA10&count LT 999998 THEN EXPENPUR = GA10&count;


  KEEP
  REGION AREA GEOUNIT1 GEOUNIT2 REGION AREA CIUDAD PROVINCE HHID NPERS FOODCD
  PURCHASE
  FREQ
  QUANTPUR
  UNIT
  EXPEND
  NONPUR
  FREQNPUR
  QUANNPUR
  UNITNPUR
  EXPENPUR;
  PROC MEANS;
  TITLE "MEANS FROM FOODITEM &count";
  FOOTNOTE "Suhas D. Parandekar, 3rd Round Ecuador LSMS, &sysday, &sysdate, &systime";
     %let count=%eval(&count+1);
     %end;
  %mend makefoo3;

DATA ONEa;
/* The raw file of food expenditures */
SET SASDATA.E98GA10;
/* Unique household ID */
HHID=CIUDAD*100000000+ ZONA*100000+ SECTOR*1000 + VIVIENDA*10 + HOGAR;
INFORMAT HHID 14.;
FORMAT HHID 14.;

RURAL=1;
IF AREA GE 2 THEN RURAL=2;

GEOUNIT1=DOMINIO*10 + RURAL;
GEOUNIT2=REGION*10 + RURAL;

PROVINCE=INT(CIUDAD/10000);


DATA ONEb;
SET SASDATA.E98GA20;

HHID=CIUDAD*100000000+ ZONA*100000+ SECTOR*1000 + VIVIENDA*10 + HOGAR;
INFORMAT HHID 14.;
FORMAT HHID 14.;

RURAL=1;
IF AREA GE 2 THEN RURAL=2;

GEOUNIT1=DOMINIO*10 + RURAL;
GEOUNIT2=REGION*10 + RURAL;

PROVINCE=INT(CIUDAD/10000);


DATA ONEc;
SET SASDATA.E98GA30;
HHID=CIUDAD*100000000+ ZONA*100000+ SECTOR*1000 + VIVIENDA*10 + HOGAR;
INFORMAT HHID 14.;
FORMAT HHID 14.;

RURAL=1;
IF AREA GE 2 THEN RURAL=2;

GEOUNIT1=DOMINIO*10 + RURAL;
GEOUNIT2=REGION*10 + RURAL;

PROVINCE=INT(CIUDAD/10000);


%makefood;
%makefo2a;
%makefo2b;
%makefoo3;

RUN;

PROC PRINTTO;
RUN;
ENDSAS;
