/* ########################################################################## */
/* STEP 5 */
/* ########################################################################## */
/* UVAL0.SAS */
/* ########################################################################## */
/* ########################################################################## */
/* Brings in non-food expenditures */

/* Calculation of non-food expenses was conducted under a different set
   of programs, using STATA - these programs are presented separately as
   NON-FOOD STEP x */

/* Written by Suhas D. Parandekar, June 17, 1999 */
/* Last updated by Suhas D. Parandekar, January 3, 2000 */

/* ########################################################################## */
/* INPUT DATA - various aggregates of non-food expenditures, created using
   Stata programs described as Non Food Step1 to Non Food Step 2, and food
   expenditure, created as FINFOOD2 in program finfood.sas */

/* OUTPUT DATA - Merged file TOTEXP - The basic household consumption aggregate */

/* OUTPUT OF DESCRIPTIVES - UVAL0.LST  provides means */

/* ########################################################################## */


OPTIONS COMPRESS=NO LS=72 NOCENTER PAGENO=1;
LIBNAME SASDATA 'P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\data\newdata\sas';

PROC PRINTTO
  LOG='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\UVAL0.LOG'
  PRINT='P:\General\Lcshd\Sdp\Ctry\Ecuador\LSMS98\Output\Food\UVAL0.LST';



/* Output   of NONFOOD STEP 6 */

DATA ONEa;SET SASDATA.TEEDUCM;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from Onea";
PROC SORT; By HHID;

DATA ONEb;SET ONEa;BY HHID;
FILE ONEc;
PUT HHID 14. NPERS FEXP RURAL AREA GEOUNIT1 GEOUNIT2 PROVINCE EXPEND;

DATA ONEd;
INFILE 'C:\Sas\Onec.dat';
INPUT HHID 14. NPERS FEXP RURAL AREA GEOUNIT1 GEOUNIT2 PROVINCE EXPEND;
PROC MEANS;
TITLE "Means from Oned";
PROC SORT;BY HHID;

/* Output   of NONFOOD STEP 1 */

DATA TWOa;SET SASDATA.DUREXP;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from TWOa";
PROC SORT; By HHID;

DATA TWOb;SET TWOa;BY HHID;
FILE TWOc;
PUT HHID 14. HHDUR2;

DATA TWOd;
INFILE 'C:\Sas\TWOc.dat';
INPUT HHID 14. HHDUR2;
PROC MEANS;
TITLE "Means from TWOd";
PROC SORT;BY HHID;

/* Output   of NONFOOD STEP 8 */


DATA THREEa;SET SASDATA.NFEXP2;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from THREEa";
PROC SORT; By HHID;

DATA THREEb;SET THREEa;BY HHID;
FILE THREEc;
PUT HHID 14. XNFOOD;

DATA THREEd;
INFILE 'C:\Sas\THREEc.dat';
INPUT HHID 14. XNFOOD;
PROC MEANS;
TITLE "Means from THREEd";
PROC SORT;BY HHID;

/* Output   of NONFOOD STEP 7 */

DATA FOURa;SET SASDATA.VIVEXP;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from FOURa";
PROC SORT; By HHID;

DATA FOURb;SET FOURa;BY HHID;
FILE FOURc;
PUT HHID 14. VI12 VI28 VI29A VI32;

DATA FOURd;
INFILE 'C:\Sas\FOURc.dat';
INPUT HHID 14. VI12 VI28 VI29A VI32;
PROC MEANS;
TITLE "Means from FOURd";
PROC SORT;BY HHID;

/* Output   of NONFOOD STEPS 2 and 3 */

DATA FIVEa;SET SASDATA.VIVRENT;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from FIVEa";
PROC SORT; By HHID;

DATA FIVEb;SET FIVEa;BY HHID;
FILE FIVEc;
PUT HHID 14. ERENT;

DATA FIVEd;
INFILE 'C:\Sas\FIVEc.dat';
INPUT HHID 14. ERENT;
PROC MEANS;
TITLE "Means from FIVEd";
PROC SORT;BY HHID;

/* Output   of FINFOOD.SAS (STEP4) */

DATA SIXa;SET SASDATA.FINFOOD2;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from SIXa";
PROC SORT; By HHID;

DATA SIXb;SET SIXa;BY HHID;
FILE SIXc;
PUT HHID 14. FOODEXP;

DATA SIXd;
INFILE 'C:\Sas\SIXc.dat';
INPUT HHID 14. FOODEXP;
PROC MEANS;
TITLE "Means from SIXd";
PROC SORT;BY HHID;

/* Output   of NONFOOD STEPS 4 and 5 */

DATA SIva;SET SASDATA.pwater;
DROP NPERS;
FORMAT HHID 14.;
PROC MEANS;
TITLE "Means from SIva";
PROC SORT; By HHID;

DATA SIvb;SET SIva;BY HHID;
FILE SIvc;
PUT HHID 14. ewater;

DATA SIVd;
INFILE 'C:\Sas\SIvc.dat';
INPUT HHID 14. ewater;
PROC MEANS;
TITLE "Means from SIvd";
PROC SORT;BY HHID;
RUN;


/* Now merge the Files */

DATA SASDATA.TOTEXP;
MERGE
ONEd Twod Threed Fourd Fived Sixd(IN=INFOOD) Sivd;
BY HHID;
IF INFOOD;
FORMAT HHID 14.;

IF EXPEND = . THEN EXPEND=0;
IF HHDUR2 = . THEN HHDUR2 = 0;
IF XNFOOD = . THEN XNFOOD=0;
IF ERENT = . THEN ERENT = 0;
IF VI12 = . THEN VI12 = 0;
IF VI28 = . THEN VI28 = 0;
IF VI29A = . THEN VI29A = 0;
IF VI32 = . THEN VI32 = 0;
IF EWATER = . THEN EWATER = 0;
IF FOODEXP= . THEN FOODEXP = 0;


TOTEXP1=EXPEND+HHDUR2+XNFOOD+ERENT+VI12+VI28+VI29A+VI32;
TOTEXP2=EXPEND+HHDUR2+XNFOOD+ERENT+VI12+VI28+VI29A+VI32+EWATER;
TOTEXP1b=TOTEXP1+(FOODEXP*2);
TOTEXP2b=TOTEXP2+(FOODEXP*2);
IF TOTEXP1b = . THEN TOTEXP1b=0;
IF TOTEXP2b = . THEN TOTEXP2b=0;

PCAP1c=TOTEXP1b/NPERS;
PCAP2c=TOTEXP2b/NPERS;


LABEL
TOTEXP1="Total Hhld Expense non-food (no water)"
TOTEXP2="Total Hhld Expense non-food (with water)"
TOTEXP1b="Total Food + Nonfood (no water)"
TOTEXP2b="Total Food + Nonfood (with water)"
PCAP1c="Per Capita (Food + Nonfood no water)"
PCAP2c="Per Capita (Food + Nonfood with water)";
PROC MEANS;
TITLE "Means from TOTEXP";

%macro count(name);
DATA ONE;SET &name;
PROC SORT; BY HHID;
DATA TWO;SET ONE;BY HHID;
REPTCODE=1;
IF FIRST.HHID THEN REPTCODE=0;
PROC FREQ; TABLES REPTCODE;
TITLE "Repeat Codes in &name";
%mend count;

%macro countp(name);
DATA ONE;SET &name;
PROC SORT; BY PID;
DATA TWO;SET ONE;BY PID;
REPTCODE=1;
IF FIRST.PID THEN REPTCODE=0;
PROC FREQ; TABLES REPTCODE;
TITLE "Repeat P Codes in &name";
%mend countp;


%count(ONed);
%count(Twod);
%count(Threed);

%count(Fourd);
%count(Fived);
%count(Sixd);
%count(Sivd);

%count(SASDATA.TOTEXP);

RUN;

PROC PRINTTO;
RUN;
